@@ -43,8 +43,8 @@
 #' @section Default aesthetics:
 #' Set by the statistic and available to geoms.
 #' \describe{
-#'   \item{color}{..wl.color..}
-#'   \item{fill}{..wl.color..}
+#'   \item{color}{after_stat(wl.color)}
+#'   \item{fill}{after_stat(wl.color)}
 #' }
 #'
 #' @section Required aesthetics:
@@ -84,7 +84,7 @@ stat_color <- function(mapping = NULL,
                        position = "identity",
                        ...,
                        chroma.type = "CMF",
-                       x.colour.transform = I,
+                       x.colour.transform = function(x) {x},
                        na.rm = FALSE,
                        show.legend = FALSE,
                        inherit.aes = TRUE) {
