@@ -113,8 +113,8 @@ stat_find_wls <- function(mapping = NULL,
                           label.fmt = "%.3g",
                           x.label.fmt = label.fmt,
                           y.label.fmt = label.fmt,
-                          x.label.transform = I,
-                          y.label.transform = I,
+                          x.label.transform = function(x) {x},
+                          y.label.transform = function(x) {x},
                           x.colour.transform = x.label.transform,
                           na.rm = FALSE,
                           show.legend = FALSE,
@@ -294,8 +294,8 @@ stat_find_qtys <- function(mapping = NULL,
                            label.fmt = "%.3g",
                            x.label.fmt = label.fmt,
                            y.label.fmt = label.fmt,
-                           x.label.transform = I,
-                           y.label.transform = I,
+                           x.label.transform = function(x) {x},
+                           y.label.transform = function(x) {x},
                            x.colour.transform = x.label.transform,
                            na.rm = FALSE,
                            show.legend = FALSE,
