@@ -135,9 +135,8 @@ stat_label_peaks <-
            position = "identity",
            ...,
            span = 5,
-           ignore_threshold = 0,
-           global.threshold = ignore_threshold,
-           strict = TRUE,
+           global.threshold = 0.01,
+           strict = FALSE,
            chroma.type = "CMF",
            label.fmt = "%.3g",
            x.label.fmt = label.fmt,
@@ -270,9 +269,8 @@ stat_label_valleys <- function(mapping = NULL,
                                position = "identity",
                                ...,
                                span = 5,
-                               ignore_threshold = 0,
-                               global.threshold = ignore_threshold,
-                               strict = TRUE,
+                               global.threshold = -0.99,
+                               strict = FALSE,
                                chroma.type = "CMF",
                                label.fmt = "%.3g",
                                x.label.fmt = label.fmt,
