@@ -1,6 +1,10 @@
 #' Integrate spectral irradiance for wavebands.
 #'
-#' \code{stat_wb_sirrad} computes areas under a curve.
+#' \code{stat_wb_sirrad} computes the mean spectral irradiance under a curve,
+#' yielding energy or photon spectral irradiance. The range(s) of wavelengths to
+#' integrate are set with a list of \code{waveband} objects.
+#' \strong{\code{x}-scale transformations and axis flipping are currently not
+#' supported}.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs
@@ -105,43 +109,14 @@
 #' @export
 #' @family stats functions
 #'
-stat_wb_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
-                       w.band = NULL,
-                       time.unit,
-                       unit.in,
-                       label.qty = "mean",
-                       label.mult = 1,
-                       chroma.type = "CMF",
-                       label.fmt = "%.3g",
-                       ypos.mult = 0.55,
-                       xpos.fixed = NULL,
-                       ypos.fixed = NULL,
-                       position = "identity", na.rm = FALSE, show.legend = NA,
-                       inherit.aes = TRUE, ...) {
-  ggplot2::layer(
-    stat = StatWbSIrrad, data = data, mapping = mapping, geom = geom,
-    position = position, show.legend = show.legend, inherit.aes = inherit.aes,
-    params = list(w.band = w.band,
-                  time.unit = time.unit,
-                  unit.in = unit.in,
-                  label.qty = label.qty,
-                  label.mult = label.mult,
-                  chroma.type = chroma.type,
-                  label.fmt = label.fmt,
-                  ypos.mult = ypos.mult,
-                  xpos.fixed = xpos.fixed,
-                  ypos.fixed = ypos.fixed,
-                  na.rm = na.rm,
-                  ...)
-  )
-}
-
-#' @rdname stat_wb_sirrad
-#' @export
-stat_wb_e_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
+stat_wb_sirrad <- function(mapping = NULL,
+                           data = NULL,
+                           geom = "text",
+                           position = "identity",
+                           ...,
                            w.band = NULL,
-                           time.unit = "second",
-                           unit.in = "energy",
+                           time.unit,
+                           unit.in,
                            label.qty = "mean",
                            label.mult = 1,
                            chroma.type = "CMF",
@@ -149,8 +124,9 @@ stat_wb_e_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
                            ypos.mult = 0.55,
                            xpos.fixed = NULL,
                            ypos.fixed = NULL,
-                           position = "identity", na.rm = FALSE, show.legend = NA,
-                           inherit.aes = TRUE, ...) {
+                           na.rm = FALSE,
+                           show.legend = NA,
+                           inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatWbSIrrad, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -171,19 +147,62 @@ stat_wb_e_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
 
 #' @rdname stat_wb_sirrad
 #' @export
-stat_wb_q_sirrad <- function(mapping = NULL, data = NULL, geom = "text",
-                           w.band = NULL,
-                           time.unit = "second",
-                           unit.in = "photon",
-                           label.qty = "mean",
-                           label.mult = 1,
-                           chroma.type = "CMF",
-                           label.fmt = "%.3g",
-                           ypos.mult = 1.07,
-                           xpos.fixed = NULL,
-                           ypos.fixed = NULL,
-                           position = "identity", na.rm = FALSE, show.legend = NA,
-                           inherit.aes = TRUE, ...) {
+stat_wb_e_sirrad <- function(mapping = NULL,
+                             data = NULL,
+                             geom = "text",
+                             position = "identity",
+                             ...,
+                             w.band = NULL,
+                             time.unit = "second",
+                             unit.in = "energy",
+                             label.qty = "mean",
+                             label.mult = 1,
+                             chroma.type = "CMF",
+                             label.fmt = "%.3g",
+                             ypos.mult = 0.55,
+                             xpos.fixed = NULL,
+                             ypos.fixed = NULL,
+                             na.rm = FALSE,
+                             show.legend = NA,
+                             inherit.aes = TRUE) {
+  ggplot2::layer(
+    stat = StatWbSIrrad, data = data, mapping = mapping, geom = geom,
+    position = position, show.legend = show.legend, inherit.aes = inherit.aes,
+    params = list(w.band = w.band,
+                  time.unit = time.unit,
+                  unit.in = unit.in,
+                  label.qty = label.qty,
+                  label.mult = label.mult,
+                  chroma.type = chroma.type,
+                  label.fmt = label.fmt,
+                  ypos.mult = ypos.mult,
+                  xpos.fixed = xpos.fixed,
+                  ypos.fixed = ypos.fixed,
+                  na.rm = na.rm,
+                  ...)
+  )
+}
+
+#' @rdname stat_wb_sirrad
+#' @export
+stat_wb_q_sirrad <- function(mapping = NULL,
+                             data = NULL,
+                             geom = "text",
+                             position = "identity",
+                             ...,
+                             w.band = NULL,
+                             time.unit = "second",
+                             unit.in = "photon",
+                             label.qty = "mean",
+                             label.mult = 1,
+                             chroma.type = "CMF",
+                             label.fmt = "%.3g",
+                             ypos.mult = 1.07,
+                             xpos.fixed = NULL,
+                             ypos.fixed = NULL,
+                             na.rm = FALSE,
+                             show.legend = NA,
+                             inherit.aes = TRUE) {
   ggplot2::layer(
     stat = StatWbSIrrad, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
