@@ -79,6 +79,12 @@ ggplot(sun.spct) +
   scale_x_wl_continuous() +
   scale_y_s.e.irrad_continuous()
 
+## -----------------------------------------------------------------------------
+ggplot(sun.spct) + 
+  geom_line() +
+  scale_x_wl_continuous(axis.symbols = FALSE) +
+  scale_y_s.e.irrad_continuous(axis.symbols = FALSE)
+
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
   geom_line() +
@@ -108,6 +114,8 @@ ggplot(sun.spct) +
                                labels = SI_tg_format(exponent = -3))
 
 ## -----------------------------------------------------------------------------
+# current version of scales shows math_format() and trans_format() as superseded!
+# y-axis tick labels are still correct in the HTML output
 temp.spct <- clean(sun.spct, range.s.data = c(1e-20, Inf), fill = 1e-20)
 ggplot(temp.spct) + 
   geom_line(na.rm = TRUE) +
@@ -121,14 +129,14 @@ ggplot(temp.spct) +
 ggplot(sun.spct) + 
   geom_line() +
   scale_x_wl_continuous(label.text = "Longitud de onda,") +
-  scale_y_s.e.irrad_continuous(label.text = "Irradiancia,")
+  scale_y_s.e.irrad_continuous(label.text = "Irradiancia espectral,")
 
 ## -----------------------------------------------------------------------------
 norm_sun.spct <- normalize(sun.spct)
 ggplot(norm_sun.spct) + 
   geom_line() +
   scale_x_wl_continuous() +
-  scale_y_s.e.irrad_continuous(normalized = getNormalized(norm_sun.spct))
+  scale_y_s.e.irrad_continuous(normalized = is_normalized(norm_sun.spct))
 
 ## -----------------------------------------------------------------------------
 scaled_sun.spct <- fscale(sun.spct)
@@ -140,27 +148,32 @@ ggplot(scaled_sun.spct) +
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
   geom_line() +
-  scale_x_wl_continuous()
+  scale_x_wl_continuous() +
+  scale_y_s.e.irrad_continuous()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, aes(x = wl2frequency(w.length), y = s.e.irrad)) + 
   geom_line() +
-  scale_x_frequency_continuous()
+  scale_x_frequency_continuous() +
+  scale_y_s.e.irrad_continuous()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
   geom_line() +
-  scale_x_wl_continuous(sec.axis = sec_axis_w_frequency())
+  scale_x_wl_continuous(sec.axis = sec_axis_w_frequency()) +
+  scale_y_s.e.irrad_continuous()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
   geom_line() +
-  scale_x_wl_continuous(sec.axis = sec_axis_energy_eV())
+  scale_x_wl_continuous(sec.axis = sec_axis_energy_eV()) +
+  scale_y_s.e.irrad_continuous()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
   geom_line() +
-  scale_x_wl_continuous(sec.axis = sec_axis_w_frequency(15))
+  scale_x_wl_continuous(sec.axis = sec_axis_w_frequency(15)) +
+  scale_y_s.e.irrad_continuous()
 
 ## -----------------------------------------------------------------------------
 ggplot(white_led.raw_spct) + 
@@ -190,7 +203,7 @@ ggplot(sun.spct) +
 ggplot(sun.spct, unit.out = "photon", range = c(293, NA)) + 
   geom_line() +
   scale_x_wl_continuous() +
-  scale_y_s.e.irrad_log10(unit.exponent = -6)
+  scale_y_s.q.irrad_log10()
 
 ## -----------------------------------------------------------------------------
 ggplot(ccd.spct) + 
@@ -337,7 +350,7 @@ ggplot(sun.spct) + geom_line() +
                    max.overlaps = Inf,
                    position = position_nudge_repel(y = 0.12),
                    min.segment.length = 0,
-                   box.padding = 0.5,
+                   box.padding = 0.25,
                    force_pull = 0) +
   expand_limits(y = 1) +
   scale_fill_identity() + 
@@ -351,7 +364,7 @@ ggplot(sun.spct) + geom_line() +
                      max.overlaps = Inf,
                      position = position_nudge_repel(y = -0.12),
                      min.segment.length = 0,
-                     box.padding = 0.53,
+                     box.padding = 0.25,
                      force = 0.5,
                      force_pull = 1) +
   scale_fill_identity() + 
@@ -379,7 +392,8 @@ ggplot(two_suns.spct) + aes(color = spct.idx) +
   stat_peaks(span = NULL, color = "black") +
   stat_peaks(span = NULL, geom = "text", vjust = -0.5, size = 3, 
              color = "black", 
-             aes(label = paste(stat(y.label), "at", after_stat(x.label), "nm"))) +
+             aes(label = paste(after_stat(y.label), "at", 
+                               after_stat(x.label), "nm"))) +
   facet_grid(rows = vars(spct.idx))
 
 ## -----------------------------------------------------------------------------
@@ -417,8 +431,7 @@ ggplot(sun.spct) +
   geom_line(color = "black") +
   geom_point(shape = 21, color = "black", stroke = 1.2, fill = "white") +
   scale_fill_identity() + 
-  scale_color_identity() + 
-  theme_bw()
+  scale_color_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + 
@@ -426,8 +439,7 @@ ggplot(sun.spct) +
   geom_line(color = "black") +
   geom_point(shape = 21, color = "black", stroke = 1.2, fill = "white") +
   scale_fill_identity() + 
-  scale_color_identity() + 
-  theme_bw()
+  scale_color_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(two_suns.spct) + aes(shape = spct.idx) +
@@ -471,8 +483,14 @@ ggplot(sun.spct) +
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
-  stat_wl_summary(range = c(400,500), geom = "rect", alpha = 0.2, fill = color_of(450)) +
-  stat_wl_summary(range = c(400,500), label.fmt = "Mean = %.3g", vjust = -0.3, geom = "text") + 
+  stat_wl_summary(range = c(400,500), 
+                  geom = "rect", 
+                  alpha = 0.2, 
+                  fill = color_of(450)) +
+  stat_wl_summary(range = c(400,500), 
+                  label.fmt = "Mean = %.3g", 
+                  vjust = -0.3, 
+                  geom = "text") + 
   geom_line()
 
 ## -----------------------------------------------------------------------------
@@ -492,41 +510,37 @@ ggplot(two_suns.spct) + aes(color = spct.idx) +
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   geom_line() + 
-  stat_wb_hbar(w.band = PAR(), size = 1.3) +
-  stat_wb_mean(aes(color = ..wb.color..), w.band = PAR(), ypos.mult = 0.95) +
+  stat_wb_hbar(w.band = PhR(), size = 1.3) +
+  stat_wb_mean(aes(color = after_stat(wb.color)), w.band = PhR(), ypos.mult = 0.95) +
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   stat_wb_hbar(w.band = c(400,500), size = 1.2) +
-  stat_wb_mean(aes(color = ..wb.color..),
+  stat_wb_mean(aes(color = after_stat(wb.color)),
                w.band = c(400,500), ypos.mult = 0.95) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   geom_line() + 
   stat_wb_hbar(w.band = list(Blue(), Red()), size = 1.2) +
-  stat_wb_mean(aes(color = ..wb.color..),
+  stat_wb_mean(aes(color = after_stat(wb.color)),
                w.band = list(Blue(), Red()), ypos.mult = 0.95, 
                hjust = 1, angle = 90) +
   scale_color_identity() + 
-  scale_fill_identity() +
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
-  stat_wb_box(w.band = PAR()) +
-  stat_wb_total(w.band = PAR()) +
+  stat_wb_box(w.band = PhR()) +
+  stat_wb_total(w.band = PhR()) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
@@ -534,8 +548,7 @@ ggplot(sun.spct) +
   stat_wb_total(w.band = c(400,500)) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct * yellow_gel.spct) +
@@ -544,8 +557,7 @@ ggplot(sun.spct * yellow_gel.spct) +
   stat_wb_mean(w.band = Plant_bands(), label.fmt = "%1.2f",
                ypos.fixed = 0.7, size = 2) +
   geom_line() + 
-  scale_fill_identity() + scale_color_identity() +
-  theme_bw()
+  scale_fill_identity() + scale_color_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
@@ -553,19 +565,19 @@ ggplot(sun.spct) +
   stat_wb_irrad(w.band = PAR(), unit.in = "energy", time.unit = "second") +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, unit.out = "photon") +
   stat_wb_box(w.band = PAR()) +
   stat_wb_irrad(w.band = PAR(),
                 unit.in = "photon", time.unit = "second", 
-                aes(label = sprintf("%s = %.3g", ..wb.name.., ..wb.yint.. * 1e6))) +
+                aes(label = sprintf("%s = %.3g", 
+                                    after_stat(wb.name),
+                                    after_stat(wb.yint) * 1e6))) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
@@ -573,8 +585,7 @@ ggplot(sun.spct) +
   stat_wb_e_irrad(w.band = PAR()) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
@@ -582,8 +593,7 @@ ggplot(sun.spct) +
   stat_wb_e_irrad(w.band = CIE()) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.daily.spct) +
@@ -591,8 +601,7 @@ ggplot(sun.daily.spct) +
   stat_wb_e_irrad(w.band = CIE(), time.unit = "day", label.mult = 1e-3) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, unit.out = "photon") +
@@ -601,18 +610,16 @@ ggplot(sun.spct, unit.out = "photon") +
   stat_wb_q_irrad(w.band = VIS_bands(), label.mult = 1e6, size = 2) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   geom_line() + 
   stat_wb_hbar(w.band = PAR(), size = 1.4) +
-  stat_wb_e_sirrad(aes(color = ..wb.color..), 
+  stat_wb_e_sirrad(aes(color = after_stat(wb.color)), 
                    w.band = PAR(), ypos.mult = 0.95) +
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, unit.out = "photon") +
@@ -620,17 +627,18 @@ ggplot(sun.spct, unit.out = "photon") +
   stat_wb_q_sirrad(w.band = PAR(), 
                    mapping =
                      aes(label = sprintf("Total %s = %.3g", 
-                                         ..wb.name.., ..wb.yint.. * 1e6)), 
+                                         after_stat(wb.name),
+                                         after_stat(wb.yint) * 1e6)), 
                    ypos.mult = 0.55) +
   stat_wb_q_sirrad(w.band = PAR(),
                    mapping = 
                      aes(label = sprintf("Mean %s = %.3g", 
-                                         ..wb.name.., ..wb.ymean.. * 1e6)), 
+                                         after_stat(wb.name), 
+                                         after_stat(wb.ymean) * 1e6)), 
                    ypos.mult = 0.45) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
@@ -638,8 +646,7 @@ ggplot(sun.spct) +
   stat_wb_e_sirrad(w.band = CIE(), ypos.fixed = 0.85) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.daily.spct) +
@@ -650,8 +657,7 @@ ggplot(sun.daily.spct) +
                    ypos.fixed = 34e3) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 my.bands <- split_bands(c(300,800), length.out = 10)
@@ -661,30 +667,31 @@ ggplot(sun.spct, unit.out = "photon") +
                    size = 2.5, ypos.fixed = 3.5e-6) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   stat_wb_column(w.band = VIS_bands(), alpha = 0.5) +
   stat_wb_e_irrad(w.band = VIS_bands(), angle = 90,
                    ypos.fixed = 0.05, hjust = 0,
-                   aes(label = paste(..wb.name.., ..y.label.., sep = " = "))) +
+                   aes(label = paste(after_stat(wb.name), 
+                                     after_stat(y.label), 
+                                     sep = " = "))) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, unit.out = "photon") +
   stat_wb_column(w.band = VIS_bands(), alpha = 0.5) +
   stat_wb_q_irrad(w.band = VIS_bands(), angle = 90, 
                   label.mult = 1e6, ypos.fixed = 1e-7, hjust = 0,
-                  aes(label = paste(..wb.name.., ..y.label.., sep = " = "))) +
+                  aes(label = paste(after_stat(wb.name), 
+                                    after_stat(y.label), 
+                                    sep = " = "))) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 my.bands <- split_bands(c(300,800), length.out = 10)
@@ -694,8 +701,7 @@ ggplot(sun.spct) +
                   ypos.fixed = 0.05, hjust = 0) +
   geom_line() + 
   scale_color_identity() + 
-  scale_fill_identity() +  
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(data.frame(w.length = 300:800), aes(w.length)) +
@@ -771,39 +777,37 @@ ggplot(my.data, aes(x)) + stat_wl_strip(ymin = -1, ymax = 1, color = NA) +
 ggplot(sun.spct) +
   geom_line() +
   stat_wl_strip(ymin = -Inf, ymax = -0.025) + 
-  scale_fill_identity() +
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   geom_line() + 
   stat_wl_strip(w.band = VIS_bands(), ymin = -Inf, ymax = -0.025) + 
-  scale_fill_identity() +
-  theme_bw()
+  scale_fill_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   stat_wl_strip(w.band = VIS_bands(), ymin = -Inf, ymax = Inf, alpha = 0.4) + 
   scale_fill_identity() +
-  geom_line() +
-  theme_bw()
+  geom_line()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) +
   stat_wl_strip(alpha = 0.4, ymin = -Inf, ymax = Inf) + 
   scale_fill_identity() +
-  geom_line() +
-  theme_bw()
+  geom_line()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct, unit.out = "photon") +
   stat_wl_strip(alpha = 0.4, ymin = -Inf, ymax = Inf) + 
   stat_wb_box(w.band = PAR()) +
-  stat_wb_total(w.band = PAR(), label.mult = 1e6,
-                aes(label = paste(..wb.name.., " = ", ..y.label.., sep = ""))) +  
+  stat_wb_q_irrad(w.band = PAR(), label.mult = 1e6,
+                  aes(label = paste(after_stat(wb.name), 
+                                    " = ", 
+                                    after_stat(y.label), 
+                                    sep = ""))) +  
   geom_line() + 
-  scale_fill_identity() + scale_color_identity() +
-  theme_bw()
+  scale_fill_identity() + scale_color_identity()
 
 ## -----------------------------------------------------------------------------
 ggplot(sun.spct) + geom_spct()
@@ -836,8 +840,7 @@ ggplot(sun.spct) +
   wl_guide() +
   geom_line(size = 2, colour = "white") +
   geom_line(size = 1, colour = "black") +
-  geom_hline(yintercept = 0, colour = "grey92") +
-  theme_bw()
+  geom_hline(yintercept = 0, colour = "grey92")
 
 ## -----------------------------------------------------------------------------
 color_chart(colors())
@@ -850,3 +853,19 @@ color_chart(grep("blue", colors(), value = TRUE), ncol = 5, text.size = 4)
             use.names = TRUE, text.size = 4) +
   ggtitle("Reddish colors", subtitle = "Labels: wavelength (nm)")
 
+## -----------------------------------------------------------------------------
+ggplot(sun.spct) + 
+  geom_line() +
+  scale_x_wl_continuous(axis.symbols = FALSE) +
+  scale_y_s.e.irrad_continuous(axis.symbols = FALSE)
+
+## -----------------------------------------------------------------------------
+old.axis.symbols <- set_axis_symbols_default(FALSE)
+
+ggplot(sun.spct) + 
+  geom_line() +
+  scale_x_wl_continuous() +
+  scale_y_s.e.irrad_continuous()
+
+set_axis_symbols_default(old.axis.symbols) # optionally restore
+
